//课程表
import {
  submit,
  batchDeletion,
  pagingQuery,
  singleQuery,
  postQueryData,
} from "../publicMethod/PublicMethod.js";
import classScheduleApi from "../api/classScheduleApi";
import { request } from "../globalConfiguration";
//课程表接口
const PagesData={ 
  semesterName:undefined,
  weekType:undefined,
  weekStart:undefined,
  weekEnd:undefined,
  classWeek:undefined,
  lessonSetDetailIds:undefined,
  classId:undefined,
  classBuildingId:undefined,
  teacherId:undefined,
  courseId:undefined,
  className:undefined,
  classBuildingName:undefined,
  teacherName:undefined,
  courseName:undefined,
}
/**
 * @Post 请求
 *添加课程表
 * @param {data} 参数 
 * {semesterName} 学期名称  *
 * {weekType} 周类型 *
 * {weekStart} 起始周 *
 * {weekEnd} 截止周 *
 * {classWeek}  上课星期 *
 * {lessonSetDetailIds}  上课节数 *
 * {classId}  教室Id *
 * {classBuildingId}  教学班Id *  
 * {teacherId}  授课老师Id *
 * {courseId}  课程Id *
 * @param {config} 配置项
 * @returns
 */
function classScheduleAdd(
  data = PagesData,
  config = {}
) {
  return request(
    submit(
      {
        xqmc: data.semesterName || undefined,//学期名称
        zlx: data.weekType || undefined,//周类型
        qsz: data.weekStart || undefined, //起始周
        jzz: data.weekEnd || undefined, //截止周
        skxq:data.classWeek || undefined, //上课星期
        lessonSetDetailIds:data.lessonSetDetailIds || undefined, //上课节数
        fkJsId: data.classId || undefined, //教室Id
        fkJxbId: data.classBuildingId || undefined, //教学班Id
        sklsid: data.teacherId || undefined, //授课老师Id
        kcid: data.courseId || undefined, // 课程Id   
      },
      classScheduleApi.classScheduleAdd,
      config
    )
  );
}

/**
 * @Post 请求
 *更新课程表
 * @param {data} 参数
 * {id} 课程id *
 * {semesterName} 学期名称  *
 * {weekType} 周类型 *
 * {weekStart} 起始周 *
 * {weekEnd} 截止周 *
 * {classWeek}  上课星期 *
 * {lessonSetDetailIds}  上课节数 *
 * {classId}  教室Id *
 * {classBuildingId}  教学班Id *  
 * {teacherId}  授课老师Id *
 * {courseId}  课程Id *
 * @param {config} 配置项
 * @returns
 */
function classScheduleUpdate(
  data = {
    id: undefined,
   ...PagesData,
  },
  config = {}
) {
  return request(
    submit(
      {
        id: data.id || undefined, //课程id
        xqmc: data.semesterName || undefined,//学期名称
        zlx: data.weekType || undefined,//周类型
        qsz: data.weekStart || undefined, //起始周
        jzz: data.weekEnd || undefined, //截止周
        skxq:data.classWeek || undefined, //上课星期
        lessonSetDetailIds:data.lessonSetDetailIds || undefined, //上课节数
        fkJsId: data.classId || undefined, //教室Id
        fkJxbId: data.classBuildingId || undefined, //教学班Id
        sklsid: data.teacherId || undefined, //授课老师Id
        kcid: data.courseId || undefined, // 课程Id   
      },
      classScheduleApi.classScheduleUpdate,
      config
    )
  );
}

/**
 * @DELETE 请求
 *批量删除课程表
 * @param {data} 参数 传入要删除的数组 []
 * @param {config} 配置项
 * @returns
 */
function classScheduleDel(data, config = {}) {
  return request(batchDeletion(data, classScheduleApi.classScheduleDel, config));
}

/**
 * @Get 请求
 *根据学期id和第几周获取学期详情
 * {semesterName} 学期名称
 * {lecturePeriod} 节课时长
 * {weekOfSemester}本学期第几周
 * {sectionDay}日节课数
 * {weekList} 星期列表
 * {weekNumber} 星期几
 * {correspondingDate} 对应日期
 * {sectionContent}节课内容
 * {associatSectionId}关联节课配置Id
 * {classStartTime}上课时间
 * {classEndTime}下课时间
 * @param {data} 参数 
 * {schoolId} 学校id
 * {week} 第几周
 * {xqId} 学期id
 * @param {config} 配置项
 * @returns
 */
function getScheduleByIdAndWeek(data, config = {}) {
  return new Promise((resolve, reject) => {
    request(singleQuery(data, classScheduleApi.getScheduleByIdAndWeek, config))
      .then(({ result }) => {
        resolve({
          id: result.fkXqId || undefined, //学期Id
          semesterName: result.xqmc || undefined, //学期名称
          lecturePeriod:result.jksc || undefined, //节课时长
          weekOfSemester:result.weekOfSemester || undefined, //本学期第几周
          sectionDay: result.rjks|| undefined, //日节课数
          weekList:
            result.rows.length > 0
              ? result.rows.map((item) => ({
                  weekId: item.week || undefined,//星期几Id
                  weekNumber: item.name || undefined,//星期几
                  correspondingDate: item.dayOfYear  || undefined, //对应日期
                }))
              : [],
          sectionContent:
            result.columns.length > 0
              ? result.columns.map((item) => ({
                  id: item.id || undefined,//节课Id
                  idx: item.idx || undefined,//第几节Id
                  associatSectionId: item.fkJkpzId || undefined,//关联节课配置
                  classStartTime: item.sksj  || undefined, //上课时间
                  classEndTime: item.xksj  || undefined, //下课时间
                }))
              : [],
        });
      })
  });
}
/**
 *查询学期列表
 * @Post 请求
 * @param {data} 参数
 * {semesterName} 学期名称  *
 * {weekType} 周类型 *
 * {weekStart} 起始周 *
 * {weekEnd} 截止周 *
 * {classWeek}  上课星期 *
 * {lessonSetDetailIds}  上课节数 *
 * {classId}  教室Id *
 * {classBuildingId}  教学班Id *  
 * {teacherId}  授课老师Id *
 * {courseId}  课程Id *
 * @param {config} 配置项
 * @returns
 */
 function classScheduleList(
  data =PagesData,
  config = {}
) {
  return new Promise((resolve, reject) => {
    request(
      postQueryData(
        {
          xqmc: data.semesterName || undefined,//学期名称
          zlx: data.weekType || undefined,//周类型
          qsz: data.weekStart || undefined, //起始周
          jzz: data.weekEnd || undefined, //截止周
          skxq:data.classWeek || undefined, //上课星期
          lessonSetDetailIds:data.lessonSetDetailIds || undefined, //上课节数
          fkJxbId: data.classBuildingId || undefined, //教学班Id
          sklsid: data.teacherId || undefined, //授课老师Id
          kcid: data.courseId || undefined, // 课程Id  
          kcmc:data.courseName || undefined, // 课程名称
          id:data.id || undefined, // id
        },
        teachingClassApi.classScheduleList,
        config
      )
    ).then(({ result }) => {
      resolve(
        result.map((item) => ({
          value: item.id || undefined,
          label: item.xqmc || undefined, //学期名称
          weekType: item.zlx || undefined, //周类型
          weekStart: item.qsz || undefined, 
          weekEnd: result.jzz ||undefined,
          classWeek: result.skxq ||undefined, 
          lessonSetDetailIds: result.lessonSetDetailIds || undefined, 
          classBuildingId:result.fkJxbId ||undefined,
          teacherId:result.sklsid ||undefined,
          courseId: result.kcid || undefined, 
          courseName:result.kcmc ||undefined,
        }))
      );
    });
  });
}
/**
 *分页查询
 * @param {data} 参数
 * {semesterName} 学期名称  *
 * {weekStart} 起始周 *
 * {weekEnd} 截止周 *
 * {classWeek}  星期 *
 * {lessonSetDetailIds}  上课节数 *
 * {className}  教室名称 *
 * {classBuildingId}  教学班Id *  
 * {teacherName}  授课老师名称 *
 * {courseName}  课程名称 *
 * 除上面参数外 其他参数可自定义
 * @param {config} 配置项
 * @returns
 */
 function listPagesTeaCla(data=PagesData, config = {}) {
  return new Promise((resolve, reject) => {
    request(
      pagingQuery(
        {
          xqmc: data.semesterName || undefined,//学期名称
          qsz: data.weekStart || undefined, //起始周
          jzz: data.weekEnd || undefined, //截止周
          skxq:data.classWeek || undefined, //星期
          lessonSetDetailIds:data.lessonSetDetailIds || undefined, //上课节数
          jsmc: data.className|| undefined,//上课课室
          jxbmc: data.classBuildingName|| undefined, //上课班级，教学班名称
          skls: data.teacherName || undefined, //授课老师名称
          kcmc:data.courseName || undefined, // 课程名称
          id:data.id || undefined, // id
          keyword:data.keyword|| undefined, // keyword
          ...data,
          ...PagesData,
        },
        teachingClassApi.listPagesTeaCla,
        config
      )
    )
      .then(({ result }) => {
        const { list, pageInfo } = result;
        resolve({
          list:
            list.length > 0
              ? list.map((item) => ({
                  id: item.id || undefined,
                  semesterName: item.xqmc || undefined,
                  weekStart: item.qsz || undefined, 
                  weekEnd: result.jzz ||undefined,
                  classWeek: result.skxq ||undefined, 
                  lessonSetDetailIds: result.lessonSetDetailIds || undefined, 
                  className: result.jsmc || undefined, 
                  classBuildingName:result.jxbmc ||undefined,
                  teacherName:result.skls ||undefined,
                  courseName:result.kcmc ||undefined,
                }))
              : [],
          pageInfo: pageInfo,
        });
      })
      .catch((err) => {
        reject(err);
      });
  });
}
export {
  classScheduleAdd,
  classScheduleUpdate,
  classScheduleDel,
  getScheduleByIdAndWeek,
  classScheduleList,
};